@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
 import time
@@ -7,6 +6,7 @@ import requests
 from hcloud.actions.client import ActionsClient
 from hcloud.certificates.client import CertificatesClient
 from hcloud.floating_ips.client import FloatingIPsClient
+from hcloud.primary_ips.client import PrimaryIPsClient
 from hcloud.networks.client import NetworksClient
 from hcloud.isos.client import IsosClient
 from hcloud.servers.client import ServersClient
@@ -18,6 +18,7 @@ from hcloud.locations.client import LocationsClient
 from hcloud.datacenters.client import DatacentersClient
 from hcloud.load_balancers.client import LoadBalancersClient
 from hcloud.load_balancer_types.client import LoadBalancerTypesClient
+from hcloud.placement_groups.client import PlacementGroupsClient
 
 from .__version__ import VERSION
 from .firewalls.client import FirewallsClient
@@ -120,6 +121,11 @@ class Client(object):
 
         :type: :class:`FloatingIPsClient <hcloud.floating_ips.client.FloatingIPsClient>`
         """
+        self.primary_ips = PrimaryIPsClient(self)
+        """PrimaryIPsClient Instance
+
+        :type: :class:`PrimaryIPsClient <hcloud.primary_ips.client.PrimaryIPsClient>`
+        """
         self.networks = NetworksClient(self)
         """NetworksClient Instance
 
@@ -149,6 +155,12 @@ class Client(object):
         :type: :class:`FirewallsClient <hcloud.firewalls.client.FirewallsClient>`
         """
 
+        self.placement_groups = PlacementGroupsClient(self)
+        """PlacementGroupsClient Instance
+
+        :type: :class:`PlacementGroupsClient <hcloud.placement_groups.client.PlacementGroupsClient>`
+        """
+
     def _get_user_agent(self):
         """Get the user agent of the hcloud-python instance with the user application name (if specified)
 
